@@ -56,28 +56,36 @@ class ElmaApiWebClient:
     __AuthTokenLiveTimestamp: float
     __SessionToken: str
     __AppToken: str
-    authorization: 'ElmaApiWebClient.Authorization'
-    workflow: 'ElmaApiWebClient.Workflow'
-    workflow_instance_service: 'ElmaApiWebClient.WorkflowInstanceService'
+    authorization: 'Authorization'
+    workflow: 'Workflow'
+    workflow_instance_service: 'WorkflowInstanceService'
 
-    def __init__(self, host_name: str, port: int, debug_mode=False) -> None:
+    def __init__(self, host_name: str = "http://localhost", port: int = 8080, debug_mode=False) -> None:
         super().__init__()
         self.host_name = host_name
         self.port = port
-        self.debug_mode: bool = debug_mode
+        self.debug_mode = debug_mode
+        self.authorization = self.init_authorization()
+        self.workflow = self.init_workflow()
+        self.workflow_instance_service = self.init_workflow_instance_service()
 
-        self.authorization = ElmaApiWebClient.Authorization(self)
-        self.workflow = ElmaApiWebClient.Workflow(self)
-        self.workflow_instance_service = ElmaApiWebClient.WorkflowInstanceService(self)
+    def init_authorization(self):
+        return ElmaApiWebClient.Authorization(self)
+
+    def init_workflow(self):
+        return ElmaApiWebClient.Workflow(self)
+
+    def init_workflow_instance_service(self):
+        return ElmaApiWebClient.WorkflowInstanceService(self)
 
     # Создание инстанса веб-клиента с автоматической авторизацией запросов
     @staticmethod
     def init_with_auth(host_name: str, port: int, debug_mode=False,
                        user_login: str = None, user_password: str = None, app_token: str = None):
         instance = ElmaApiWebClient(host_name=host_name, port=port, debug_mode=debug_mode)
-        auth_result = ElmaApiWebClient.Authorization(instance).login_with_user_name(user_login=user_login,
-                                                                                    user_password=user_password,
-                                                                                    app_token=app_token)
+        auth_result = instance.authorization.login_with_user_name(user_login=user_login,
+                                                                  user_password=user_password,
+                                                                  app_token=app_token)
         instance.set_auth_token(auth_result.AuthToken)
         instance.set_session_token(auth_result.SessionToken)
         instance.set_app_token(app_token)
@@ -137,6 +145,9 @@ class ElmaApiWebClient:
     def set_app_token(self, app_token):
         self.__AppToken = app_token
 
+    def set_debug_mode(self, mode: bool):
+        self.debug_mode = mode
+
     # Получить токен из кэша. Если токен уже просрочен, то получить новый и закэшировать
     def get_cached_auth_token(self):
         date_now = datetime.now()
@@ -228,6 +239,7 @@ class ElmaApiWebClient:
             self.elma_client = elma
 
     class Authorization(ApiModule):
+
         # метод авторизации
         def login_with_user_name(self, user_login: str = None, user_password: str = None,
                                  app_token: str = None) -> AuthResponse:
@@ -320,13 +332,13 @@ class ElmaApiWebClient:
                                                 rsp_cls=StartProcessAsyncRs,
                                                 auth_token=auth_token, session_token=session_token)
 
-        def start_process_form(self, start_process_from_rq: StartProcessFromRq = None,
-                               process_header_id=None,
-                               auth_token: str = None, session_token: str = None) -> StartProcessFromRs:
+        def start_process_form(self, start_process_from_rq: StartProcessFormRq = None,
+                               process_header_id: int = None,
+                               auth_token: str = None, session_token: str = None) -> StartProcessFormRs:
             if start_process_from_rq is None:
-                start_process_from_rq = StartProcessFromRq(process_header_id)
+                start_process_from_rq = StartProcessFormRq(process_header_id)
             return self.__workflow_post_request(path=start_process_form_path, rq=start_process_from_rq,
-                                                rsp_cls=StartProcessFromRs,
+                                                rsp_cls=StartProcessFormRs,
                                                 auth_token=auth_token, session_token=session_token)
 
         def execute_user_task(self, execute_user_task_rq: ExecuteUserTaskRq = None,
@@ -338,14 +350,14 @@ class ElmaApiWebClient:
                                                 rsp_cls=ExecuteUserTaskRs,
                                                 auth_token=auth_token, session_token=session_token)
 
-        def execute_user_task_async(self, execute_user_task_async_rq: ExecuteUserTaskRq,
-                                    _id, context, selected_connector_uid,
-                                    auth_token: str = None, session_token: str = None) -> ExecuteUserTaskRs:
+        def execute_user_task_async(self, execute_user_task_async_rq: ExecuteUserTaskAsyncRq = None,
+                                    _id=None, context=None, selected_connector_uid=None,
+                                    auth_token: str = None, session_token: str = None) -> ExecuteUserTaskAsyncRs:
 
             if execute_user_task_async_rq is None:
-                execute_user_task_async_rq = ExecuteUserTaskRq(_id, context, selected_connector_uid)
+                execute_user_task_async_rq = ExecuteUserTaskAsyncRq(_id, context, selected_connector_uid)
             return self.__workflow_post_request(path=execute_user_task_async_path, rq=execute_user_task_async_rq,
-                                                rsp_cls=ExecuteUserTaskRs,
+                                                rsp_cls=ExecuteUserTaskAsyncRs,
                                                 auth_token=auth_token, session_token=session_token)
 
         def execute_user_task_status(self, execute_user_task_status_rq: ExecuteUserTaskStatusRq = None,
